/* about.pov
 * BRG help.about image.
 * ratio 16:9, render WxH 480x270.
 */

#version 3.7;

#local BRGversion = "0.1.5";

#local UseRadiosity = yes;

global_settings {
  assumed_gamma 2.2
  charset utf8
  max_trace_level 20
#if (UseRadiosity)
  radiosity {
    pretrace_start .08
    pretrace_end .004
    count 500
    error_bound .002
    recursion_limit 2
    normal on
  }
#end
}

#include "colours_x11.inc"
#include "BorderChars.inc"

#local CameraZ = 12;

camera {
  orthographic
  location <0, 0, -CameraZ>
  direction <0, 0, 1>
  right x * (image_width / image_height)
  look_at <0, 0, 0>
  angle 86
}

#if (UseRadiosity)
#local Dome = object {
  difference {
    sphere {0, 20001}
    sphere {0, 20000}
  }
  texture {
    pigment {
      gradient z
      color_map {
        [0, 1 color White * 2.21 color White * .6]
      }
    }
    finish {emission 1 diffuse 0}
    scale <1, 1, 20000>
  }
  no_reflection
}
object {Dome}
#else
light_source {<60, 80, -200> color White * 1.65 shadowless}
#end


#local TextColor_Outer = texture {pigment {color White}}

#local TextColor_Inner = texture {TextColor_Outer}

#local TextColor_Back = texture {pigment {color Black}}

#local BackgroundColor = texture {pigment {color <0.8834, 0.8494, 0.7747>}}

#macro CreateTexture_Gradient_Y (Color0, Color1)
texture {
  pigment {
    gradient y
    color_map {
      [0 color Color0]
      [.4 color (Color0 * 75 + Color1 * 25) / 100]
      [.6 color (Color0 + Color1) / 2]
      [1 color Color1]
    }
  }
  finish {emission .1}
  #local YScaleAdd_Bottom = .75 / 2 * .95; //Height of the bottom of the "g"
  #local YScaleAdd_Top = .075;             //Height of the top of the "*"
  scale <1, 1 + YScaleAdd_Bottom + YScaleAdd_Top, 1>
  translate -YScaleAdd_Bottom * y
}
#end

#macro CreateTexture_Gradient_X (Color0, Color1, Width)
#local Color0_ = (Color0 + White * 2) / 3;
#local Color1_ = (Color1 + White * 2) / 3;
texture {
  pigment {
    gradient x
    color_map {
      [0 color Color0_]
      [1 color Color1_]
    }
  }
  finish {emission .1}
  scale <Width + .02, 1, 1>
  translate -.01 * x
}
#end






#local FontVariationNumber = 21;
#local TextDepth = .1;
#local InvisibleBorderWidth = 0;
#local BorderWidth = .03;
#local BorderDepth = .05;


#local TextColor_Inner = CreateTexture_Gradient_Y (dark_slate_blue, Aquamarine4)
SetFontStyle (1, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, 999, 999, 999, 999, 999, TextColor_Outer, TextColor_Inner, TextColor_Back)

#local TextColor_Inner = CreateTexture_Gradient_Y (Orange, OrangeRed)
SetFontStyle (2, FontVariationNumber, TextDepth, InvisibleBorderWidth, BorderWidth, BorderDepth, 999, 999, 999, 999, 999, TextColor_Outer, TextColor_Inner, TextColor_Back)




#local TextScale = 1.85;
#local UseActualParagraphHeight = yes;

#local LeftMargin = -CameraZ / 1.125 + .6;
#local TopMargin = CameraZ / 2 - .5;
#local ZOffset = -.1;

#declare GAP_Width = .06;  //Distance between characters
#declare SPACE_Width = .26; //Distance between words
#declare LineSpacing = .5; //Distance between lines

#declare LineAlignment = CENTERED;
#declare MaxMicroJustificationScale = 1;
#declare MaxAdditionalGAP_WidthPercentage = UNLIMITED;
#declare SPACE_ExpansionRate = 1.5;
#declare JustifyLastLinePercentage = 95;
#declare MinJustifiedParagraphWidth = 0;
#local NLines = 1;
InitializeVariables (NLines)
#declare LineText [0] = "~1~Black's Road Game";
CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
#local LeftMargin = -(ParagraphWidth / 2);
#local Message1 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

#local TopMargin = TopMargin - ParagraphHeight - LineSpacing - .5;
#local TopMargin_Save = TopMargin;
#local TextScale = 1;
#declare LineAlignment = CENTERED;
#declare MaxMicroJustificationScale = 1;
#declare MaxAdditionalGAP_WidthPercentage = UNLIMITED;
#declare SPACE_ExpansionRate = 1.5;
#declare JustifyLastLinePercentage = 95;
#declare MinJustifiedParagraphWidth = 0;
#local NLines = 1;
InitializeVariables (NLines)
#declare LineText [0] = "~1~@  solitaire  @";
CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
#local LeftMargin = -(ParagraphWidth / 2);
#local Message2 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

#local TextScale = .75;
#local TopMargin = TopMargin - ParagraphHeight - 3.15 * LineSpacing;
#local TopMargin_Save = TopMargin;
#declare LineAlignment = CENTERED;
#declare MaxMicroJustificationScale = 1;
#declare MaxAdditionalGAP_WidthPercentage = UNLIMITED;
#declare SPACE_ExpansionRate = 1.5;
#declare JustifyLastLinePercentage = 95;
#declare MinJustifiedParagraphWidth = 0;
#local NLines = 1;
InitializeVariables (NLines)
#declare LineText [0] = concat("~2~", "brg v ",BRGversion);
CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
#local LeftMargin = -(ParagraphWidth / 2);
#local Message3 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}

#local TextScale = .875;
#local TopMargin = TopMargin - ParagraphHeight - 2.25 * LineSpacing;
#local TopMargin_Save = TopMargin;
#declare LineAlignment = CENTERED;
#declare LineSpacing = 1.5;
#declare MaxMicroJustificationScale = 2;
#declare MaxAdditionalGAP_WidthPercentage = UNLIMITED;
#declare SPACE_ExpansionRate = 1.5;
#declare JustifyLastLinePercentage = 95;
#declare MinJustifiedParagraphWidth = 0;
#local NLines = 2;
InitializeVariables (NLines)
#declare LineText [0] = "~1~copyright (c) 2017 jr.  all rights reserved.";
#declare LineText [1] = "~1~<creature.eternal^gmail.com>";
CreateParagraph (NLines, TextScale, UseActualParagraphHeight)
#local LeftMargin = -(ParagraphWidth / 2);
#local Message4 = object {Paragraph translate <LeftMargin, TopMargin, ZOffset>}


object {Message1}
object {Message2}
object {Message3}
object {Message4}
#local Background = object {
  plane {
    z, 0 inverse
    pigment {Gray4}
  } 
}

object {Background}
